/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.taglib.clay.servlet.taglib.util;

import java.util.function.Consumer;

/**
 * Defines a {@code Consumer} that can throw an exception.
 *
 * <p>
 * This interface can be implemented with a lambda function.
 * </p>
 *
 * @author Carlos Lancha
 * @param  <A> the type of the first argument of the consumer
 */
@FunctionalInterface
public interface SafeConsumer<A> {

	public static <T> Consumer<T> ignore(SafeConsumer<T> safeConsumer) {
		return t -> {
			try {
				safeConsumer.accept(t);
			}
			catch (Exception e) {
				throw new RuntimeException(e);
			}
		};
	}

	/**
	 * Operates with one parameter and returns {@code void}. This function can
	 * be implemented explicitly or with a lambda.
	 *
	 * @param a the first function argument
	 */
	public void accept(A a) throws Exception;

}